@@ -28,9 +28,12 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <math.h>
+#ifdef WIN32
+#include <windows.h>
+#endif
 #include <GL/gl.h>
 #include "maverik.h"
-#include "mav_avatar.h"
+#include "mav_escapeavatar.h"
 #include "city_macros.h"
 #include "city_types.h"
 
