@@ -31,6 +31,9 @@
 #include <string.h>
 #include <math.h>
 #include <stdlib.h>
+#ifdef WIN32
+#include <windows.h>
+#endif
 #include <GL/glu.h>
 
 extern MAV_BB city_bb;
@@ -265,7 +268,7 @@ void Make_Font(void)
 
     /* read number of polygons */
     fscanf(file, "%d", &alphabet[c].num_polys);
-    alphabet[c].polys= mav_malloc(alphabet[c].num_polys*sizeof(Polygon));
+    alphabet[c].polys= mav_malloc(alphabet[c].num_polys*sizeof(LC_Polygon));
 
     /* read each polygon */
     for (i=0; i<alphabet[c].num_polys; i++) {
@@ -407,7 +410,7 @@ void Build_Feature(FILE *file, int type)
   gluDeleteTess(tobj);
 
   /* allocate space for polygons */
-  feature->polys= mav_malloc(feature->num_polys*sizeof(Polygon));
+  feature->polys= mav_malloc(feature->num_polys*sizeof(LC_Polygon));
   for (i=0; i<feature->num_polys; i++) {
     feature->polys[i].verts= mav_malloc(3*sizeof(MAV_vector));
     feature->polys[i].num_verts= 0;
