@@ -41,8 +41,13 @@
 #include <math.h>
 #include "lcity2_colour.h"
 #include <string.h>
+#ifdef WIN32
+#include <windows.h>
+#endif
 #include <GL/glu.h>
+#if 0
 #include <sys/time.h>
+#endif
 
 #include "build.h"
 
@@ -96,7 +101,6 @@ MAV_surfaceParams *stone=NULL;
 float map_scale=0.11;
 
 int drawMap=1;
-struct timeval lastBlink;
 
 MAV_class *mav_class_character;
 MAV_class *mav_class_feature;
@@ -698,7 +702,7 @@ void Make_Font(void)
 
     /* read number of polygons */
     fscanf(file, "%d", &alphabet[c].num_polys);
-    alphabet[c].polys= mav_malloc(alphabet[c].num_polys*sizeof(Polygon));
+    alphabet[c].polys= mav_malloc(alphabet[c].num_polys*sizeof(LC_Polygon));
 
     /* read each polygon */
     for (i=0; i<alphabet[c].num_polys; i++) {
@@ -888,7 +892,7 @@ void Build_Feature(float *xp, float *yp, float *zp, int num_verts, int type)
   gluDeleteTess(tobj);
 
   /* allocate space for polygons */
-  feature->polys= mav_malloc(feature->num_polys*sizeof(Polygon));
+  feature->polys= mav_malloc(feature->num_polys*sizeof(LC_Polygon));
   for (i=0; i<feature->num_polys; i++) {
     feature->polys[i].verts= mav_malloc(3*sizeof(MAV_vector));
     feature->polys[i].num_verts= 0;
@@ -2381,10 +2385,12 @@ float yscale=0.0;
 FILE *conffile;
 int saveflag;
 
+#if 0
 struct timeval prevTime;
 struct timezone prevZone;
 struct timeval thisTime;
 struct timezone thisZone;
+#endif
 int firsttime = 1;
 float timediff;
 
